@@ -140,6 +140,15 @@ MainWindow::MainWindow(QWidget *parent)
         m_nextButton->setVisible(galleryFileCount > 1);
     });
 
+    connect(m_pm, &PlaylistManager::currentIndexChanged, this, [this]() {
+        int index;
+        QUrl url;
+        std::tie(index, url) = m_pm->currentFileUrl();
+        if (index != -1) {
+            this->setWindowTitle(url.fileName());
+        }
+    });
+
     QShortcut * fullscreenShorucut = new QShortcut(QKeySequence(QKeySequence::FullScreen), this);
     connect(fullscreenShorucut, &QShortcut::activated,
             this, &MainWindow::toggleFullscreen);
@@ -309,13 +318,13 @@ void MainWindow::mousePressEvent(QMouseEvent *event)
 void MainWindow::mouseMoveEvent(QMouseEvent *event)
 {
     if (event->buttons() & Qt::LeftButton && m_clickedOnWindow && !isMaximized()) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
         if (!window()->windowHandle()->startSystemMove()) {
-            move(event->globalPos() - m_oldMousePos);
-        }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            move(event->globalPosition().toPoint() - m_oldMousePos);
 #else
-        move(event->globalPos() - m_oldMousePos);
-#endif // QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            move(event->globalPos() - m_oldMousePos);
+#endif // QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        }
         event->accept();
     }
 
