@@ -4,42 +4,42 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../aboutdialog.cpp" line="23"/>
+        <location filename="../aboutdialog.cpp" line="27"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="26"/>
+        <location filename="../aboutdialog.cpp" line="30"/>
         <source>Launch application with image file path as argument to load the file.</source>
         <translation>Inicia la aplicación con la ruta del archivo de la imagen como argumento para cargar la imagen.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="27"/>
+        <location filename="../aboutdialog.cpp" line="31"/>
         <source>Drag and drop image file onto the window is also supported.</source>
         <translation>También es posible arrastrar y soltar un archivo de imagen en la ventana.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="28"/>
+        <location filename="../aboutdialog.cpp" line="32"/>
         <source>None of the operations in this application will alter the pictures on disk.</source>
         <translation>Ninguna de las operaciones en esta aplicación alterará los archivos de imagen.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="29"/>
+        <location filename="../aboutdialog.cpp" line="33"/>
         <source>Context menu option explanation:</source>
         <translation>Explicación de las opciones del menú contextual:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="36"/>
+        <location filename="../aboutdialog.cpp" line="40"/>
         <source>Make window stay on top of all other windows.</source>
         <translation>Mantiene la ventana encima de todas las demás ventanas.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="39"/>
+        <location filename="../aboutdialog.cpp" line="43"/>
         <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
         <translation>Evita que se cierre la ventana accidentalmente (por ejemplo, al hacer doble clic en la ventana)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="47"/>
+        <location filename="../aboutdialog.cpp" line="51"/>
         <source>Version: %1</source>
         <translation>Versión: %1</translation>
     </message>
@@ -48,124 +48,124 @@
         <translation type="vanished">Derechos reservados (c) 2020 %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="53"/>
+        <location filename="../aboutdialog.cpp" line="57"/>
         <source>Logo designed by %1</source>
         <translation>Logo diseñado por %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="55"/>
+        <location filename="../aboutdialog.cpp" line="59"/>
         <source>Built with Qt %1 (%2)</source>
         <translation>Creado con Qt %1 (%2)</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="56"/>
+        <location filename="../aboutdialog.cpp" line="60"/>
         <source>Source code</source>
         <translation>Código fuente</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="66"/>
+        <location filename="../aboutdialog.cpp" line="70"/>
         <source>Contributors</source>
         <translation>Colaboradores</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="68"/>
+        <location filename="../aboutdialog.cpp" line="72"/>
         <source>List of contributors on GitHub</source>
         <translation>Lista de colaboradores en GitHub</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="69"/>
+        <location filename="../aboutdialog.cpp" line="73"/>
         <source>Thanks to all people who contributed to this project.</source>
         <translation>Gracias a todas las personas que han colaborado en este proyecto.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="73"/>
+        <location filename="../aboutdialog.cpp" line="77"/>
         <source>Translators</source>
         <translation>Traductores</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="74"/>
+        <location filename="../aboutdialog.cpp" line="78"/>
         <source>I would like to thank the following people who volunteered to translate this application.</source>
         <translation>Me gustaría dar las gracias a las personas siguientes por ofrecerse a traducir esta aplicación.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="118"/>
+        <location filename="../aboutdialog.cpp" line="122"/>
         <source>%1 is built on the following free software libraries:</source>
         <comment>Free as in freedom</comment>
         <translation>%1 está construido sobre las bibliotecas de software libre siguientes:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="142"/>
+        <location filename="../aboutdialog.cpp" line="146"/>
         <source>&amp;Special Thanks</source>
         <translation>Agradecimiento &amp;especial</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="144"/>
+        <location filename="../aboutdialog.cpp" line="148"/>
         <source>&amp;Third-party Libraries</source>
         <translation>&amp;Bibliotecas de terceros</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="80"/>
+        <location filename="../aboutdialog.cpp" line="84"/>
         <source>Your Rights</source>
         <translation>Sus derechos</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="50"/>
+        <location filename="../aboutdialog.cpp" line="54"/>
         <source>Copyright (c) %1 %2</source>
         <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
         <translation>Copyright (c) %1 %2</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="82"/>
+        <location filename="../aboutdialog.cpp" line="86"/>
         <source>%1 is released under the MIT License.</source>
         <translation>%1 se publica bajo la licencia MIT.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="83"/>
+        <location filename="../aboutdialog.cpp" line="87"/>
         <source>This license grants people a number of freedoms:</source>
         <translation>Esta licencia otorga a las personas una serie de libertades:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="84"/>
+        <location filename="../aboutdialog.cpp" line="88"/>
         <source>You are free to use %1, for any purpose</source>
         <translation>Es libre de usar %1 para cualquier propósito</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="85"/>
+        <location filename="../aboutdialog.cpp" line="89"/>
         <source>You are free to distribute %1</source>
         <translation>Es libre de distribuir %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="86"/>
+        <location filename="../aboutdialog.cpp" line="90"/>
         <source>You can study how %1 works and change it</source>
         <translation>Puede estudiar cómo funciona %1 y modificarlo</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="87"/>
+        <location filename="../aboutdialog.cpp" line="91"/>
         <source>You can distribute changed versions of %1</source>
         <translation>Puede distribuir versiones modificadas de %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="89"/>
+        <location filename="../aboutdialog.cpp" line="93"/>
         <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
         <translation>La licencia MIT le garantiza esta libertad. Nadie está autorizado a quitársela.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="117"/>
+        <location filename="../aboutdialog.cpp" line="121"/>
         <source>Third-party Libraries used by %1</source>
         <translation>Bibliotecas de terceros usadas por %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="140"/>
+        <location filename="../aboutdialog.cpp" line="144"/>
         <source>&amp;Help</source>
         <translation>Ay&amp;uda</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="141"/>
+        <location filename="../aboutdialog.cpp" line="145"/>
         <source>&amp;About</source>
         <translation>&amp;Acerca de</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="143"/>
+        <location filename="../aboutdialog.cpp" line="147"/>
         <source>&amp;License</source>
         <translation>&amp;Licencia</translation>
     </message>
@@ -173,7 +173,7 @@
 <context>
     <name>GraphicsScene</name>
     <message>
-        <location filename="../graphicsscene.cpp" line="57"/>
+        <location filename="../graphicsscene.cpp" line="90"/>
         <source>Drag image here</source>
         <translation>Arrastre una imagen aquí</translation>
     </message>
@@ -181,28 +181,28 @@
 <context>
     <name>GraphicsView</name>
     <message>
-        <location filename="../graphicsview.cpp" line="333"/>
+        <location filename="../graphicsview.cpp" line="338"/>
         <source>File url list is empty</source>
         <translation>La lista de ubicaciones está vacía</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="52"/>
+        <location filename="../graphicsview.cpp" line="56"/>
         <source>File is not a valid image</source>
         <translation>El archivo no es una imagen válida</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="57"/>
-        <location filename="../graphicsview.cpp" line="62"/>
+        <location filename="../graphicsview.cpp" line="61"/>
+        <location filename="../graphicsview.cpp" line="66"/>
         <source>Image data is invalid or currently unsupported</source>
         <translation>Los datos de la imagen no son válidos o no son compatibles</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="341"/>
+        <location filename="../graphicsview.cpp" line="346"/>
         <source>Image data is invalid</source>
         <translation>Los datos de la imagen no son válidos</translation>
     </message>
     <message>
-        <location filename="../graphicsview.cpp" line="348"/>
+        <location filename="../graphicsview.cpp" line="353"/>
         <source>Not supported mimedata: %1</source>
         <translation>El tipo MIME no es compatible: %1</translation>
     </message>
@@ -210,120 +210,120 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="160"/>
+        <location filename="../mainwindow.cpp" line="170"/>
         <source>File url list is empty</source>
         <translation>La lista de ubicaciones está vacía</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="403"/>
+        <location filename="../mainwindow.cpp" line="413"/>
         <source>&amp;Copy</source>
         <translation>&amp;Copiar</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="83"/>
+        <location filename="../actionmanager.cpp" line="102"/>
         <source>Copy P&amp;ixmap</source>
-        <translation>Copiar el &amp;mapa de píxeles</translation>
+        <translation>Copiar &amp;mapa de píxeles</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="84"/>
+        <location filename="../actionmanager.cpp" line="103"/>
         <source>Copy &amp;File Path</source>
-        <translation>Copiar la &amp;ruta del archivo</translation>
+        <translation>Copiar &amp;ruta de archivo</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="100"/>
+        <location filename="../actionmanager.cpp" line="119"/>
         <source>Properties</source>
         <translation>Propiedades</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="35"/>
-        <location filename="../actionmanager.cpp" line="86"/>
+        <location filename="../aboutdialog.cpp" line="39"/>
+        <location filename="../actionmanager.cpp" line="105"/>
         <source>Stay on top</source>
         <translation>Mantener encima</translation>
     </message>
     <message>
-        <location filename="../aboutdialog.cpp" line="38"/>
-        <location filename="../actionmanager.cpp" line="87"/>
+        <location filename="../aboutdialog.cpp" line="42"/>
+        <location filename="../actionmanager.cpp" line="106"/>
         <source>Protected mode</source>
         <translation>Modo protegido</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="72"/>
+        <location filename="../actionmanager.cpp" line="91"/>
         <source>Zoom in</source>
         <translation>Ampliar</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="73"/>
+        <location filename="../actionmanager.cpp" line="92"/>
         <source>Zoom out</source>
         <translation>Reducir</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="80"/>
+        <location filename="../actionmanager.cpp" line="99"/>
         <source>Flip &amp;Horizontally</source>
         <translation>Voltear &amp;horizontalmente</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="85"/>
+        <location filename="../actionmanager.cpp" line="104"/>
         <source>&amp;Paste</source>
         <translation>&amp;Pegar</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="74"/>
+        <location filename="../actionmanager.cpp" line="93"/>
         <source>Toggle Checkerboard</source>
         <translation>Activar/desactivar el tablero de ajedrez</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="68"/>
+        <location filename="../actionmanager.cpp" line="87"/>
         <source>&amp;Open...</source>
         <translation>&amp;Abrir...</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="70"/>
+        <location filename="../actionmanager.cpp" line="89"/>
         <source>Actual size</source>
         <translation>Tamaño real</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="71"/>
+        <location filename="../actionmanager.cpp" line="90"/>
         <source>Toggle maximize</source>
         <translation>Maximizar/desmaximizar</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="75"/>
+        <location filename="../actionmanager.cpp" line="94"/>
         <source>Rotate right</source>
         <translation>Girar a la derecha</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="77"/>
+        <location filename="../actionmanager.cpp" line="96"/>
         <source>Previous image</source>
         <translation>Imagen anterior</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="78"/>
+        <location filename="../actionmanager.cpp" line="97"/>
         <source>Next image</source>
         <translation>Imagen siguiente</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="88"/>
+        <location filename="../actionmanager.cpp" line="107"/>
         <source>Configure...</source>
         <translation>Configurar...</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="89"/>
+        <location filename="../actionmanager.cpp" line="108"/>
         <source>Help</source>
         <translation>Ayuda</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="92"/>
+        <location filename="../actionmanager.cpp" line="111"/>
         <source>Show in File Explorer</source>
         <comment>File Explorer is the name of explorer.exe under Windows</comment>
-        <translation>Mostrar en el gestor de archivos</translation>
+        <translation>Mostrar en el Explorador de archivos</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="98"/>
+        <location filename="../actionmanager.cpp" line="117"/>
         <source>Show in directory</source>
         <translation>Mostrar en la carpeta</translation>
     </message>
     <message>
-        <location filename="../actionmanager.cpp" line="101"/>
+        <location filename="../actionmanager.cpp" line="120"/>
         <source>Quit</source>
         <translation>Salir</translation>
     </message>
@@ -331,7 +331,7 @@
 <context>
     <name>MetadataDialog</name>
     <message>
-        <location filename="../metadatadialog.cpp" line="80"/>
+        <location filename="../metadatadialog.cpp" line="84"/>
         <source>Image Metadata</source>
         <translation>Metadatos de la imagen</translation>
     </message>
@@ -339,304 +339,314 @@
 <context>
     <name>MetadataModel</name>
     <message>
-        <location filename="../metadatamodel.cpp" line="37"/>
+        <location filename="../metadatamodel.cpp" line="41"/>
         <source>Origin</source>
         <comment>Section name.</comment>
         <translation>Origen</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="38"/>
+        <location filename="../metadatamodel.cpp" line="42"/>
         <source>Image</source>
         <comment>Section name.</comment>
         <translation>Imagen</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="42"/>
+        <location filename="../metadatamodel.cpp" line="46"/>
         <source>File</source>
         <comment>Section name.</comment>
         <translation>Archivo</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="39"/>
+        <location filename="../metadatamodel.cpp" line="43"/>
         <source>Camera</source>
         <comment>Section name.</comment>
         <translation>Cámara</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="29"/>
+        <location filename="../metadatamodel.cpp" line="33"/>
         <source>%1 File</source>
         <translation>Archivo %1</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="36"/>
+        <location filename="../metadatamodel.cpp" line="40"/>
         <source>Description</source>
         <comment>Section name.</comment>
         <translation>Descripción</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="40"/>
+        <location filename="../metadatamodel.cpp" line="44"/>
         <source>Advanced photo</source>
         <comment>Section name.</comment>
         <translation>Foto avanzada</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="41"/>
+        <location filename="../metadatamodel.cpp" line="45"/>
         <source>GPS</source>
         <comment>Section name.</comment>
         <translation>GPS</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="46"/>
+        <location filename="../metadatamodel.cpp" line="50"/>
         <source>Dimensions</source>
         <translation>Dimensiones</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="48"/>
+        <location filename="../metadatamodel.cpp" line="52"/>
         <source>Aspect ratio</source>
         <translation>Relación de aspecto</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="52"/>
+        <location filename="../metadatamodel.cpp" line="56"/>
         <source>Frame count</source>
         <translation>Núm. de imágenes</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="56"/>
+        <location filename="../metadatamodel.cpp" line="60"/>
         <source>Name</source>
         <translation>Nombre</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="58"/>
+        <location filename="../metadatamodel.cpp" line="62"/>
         <source>Item type</source>
         <translation>Tipo de elemento</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="60"/>
+        <location filename="../metadatamodel.cpp" line="64"/>
         <source>Folder path</source>
         <translation>Ruta de la carpeta</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="62"/>
+        <location filename="../metadatamodel.cpp" line="66"/>
         <source>Size</source>
         <translation>Tamaño</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="64"/>
+        <location filename="../metadatamodel.cpp" line="68"/>
         <source>Date created</source>
         <translation>Fecha de creación</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="66"/>
+        <location filename="../metadatamodel.cpp" line="70"/>
         <source>Date modified</source>
         <translation>Fecha de modificación</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="73"/>
+        <location filename="../metadatamodel.cpp" line="77"/>
         <source>Title</source>
         <translation>Título</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="75"/>
+        <location filename="../metadatamodel.cpp" line="79"/>
         <source>Subject</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="77"/>
+        <location filename="../metadatamodel.cpp" line="81"/>
         <source>Rating</source>
         <translation>Valoración</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="79"/>
+        <location filename="../metadatamodel.cpp" line="83"/>
         <source>Tags</source>
         <translation>Etiquetas</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="81"/>
+        <location filename="../metadatamodel.cpp" line="85"/>
         <source>Comments</source>
         <translation>Comentarios</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="84"/>
+        <location filename="../metadatamodel.cpp" line="88"/>
         <source>Authors</source>
         <translation>Autores</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="86"/>
+        <location filename="../metadatamodel.cpp" line="90"/>
         <source>Date taken</source>
         <translation>Fecha en que se tomó</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="92"/>
+        <location filename="../metadatamodel.cpp" line="96"/>
         <source>Program name</source>
         <translation>Nombre del programa</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="94"/>
+        <location filename="../metadatamodel.cpp" line="98"/>
         <source>Copyright</source>
         <translation>Copyright</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="97"/>
+        <location filename="../metadatamodel.cpp" line="101"/>
         <source>Horizontal resolution</source>
         <translation>Resolución horizontal</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="99"/>
+        <location filename="../metadatamodel.cpp" line="103"/>
         <source>Vertical resolution</source>
         <translation>Resolución vertical</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="101"/>
+        <location filename="../metadatamodel.cpp" line="105"/>
         <source>Resolution unit</source>
         <translation>Unidad de resolución</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="103"/>
+        <location filename="../metadatamodel.cpp" line="107"/>
         <source>Colour representation</source>
         <translation>Representación del color</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="106"/>
+        <location filename="../metadatamodel.cpp" line="110"/>
         <source>Camera maker</source>
         <translation>Fabricante de la cámara</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="108"/>
+        <location filename="../metadatamodel.cpp" line="112"/>
         <source>Camera model</source>
         <translation>Modelo de la cámara</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="110"/>
+        <location filename="../metadatamodel.cpp" line="114"/>
         <source>F-stop</source>
         <translation>Relación focal</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="112"/>
+        <location filename="../metadatamodel.cpp" line="116"/>
         <source>Exposure time</source>
         <translation>Tiempo de exposición</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="114"/>
+        <location filename="../metadatamodel.cpp" line="118"/>
         <source>ISO speed</source>
         <translation>Sensibilidad ISO</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="116"/>
+        <location filename="../metadatamodel.cpp" line="120"/>
         <source>Exposure bias</source>
         <translation>Compensación de exposición</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="118"/>
+        <location filename="../metadatamodel.cpp" line="122"/>
         <source>Focal length</source>
         <translation>Distancia focal</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="120"/>
+        <location filename="../metadatamodel.cpp" line="124"/>
         <source>Max aperture</source>
         <translation>Apertura máxima</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="122"/>
+        <location filename="../metadatamodel.cpp" line="126"/>
         <source>Metering mode</source>
         <translation>Modo de medición</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="124"/>
+        <location filename="../metadatamodel.cpp" line="128"/>
+        <source>Subject distance</source>
+        <translation>Distancia del sujeto</translation>
+    </message>
+    <message>
+        <location filename="../metadatamodel.cpp" line="130"/>
         <source>Flash mode</source>
         <translation>Modo del flash</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="126"/>
+        <location filename="../metadatamodel.cpp" line="132"/>
         <source>35mm focal length</source>
         <translation>Distancia focal de 35 mm</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="129"/>
+        <location filename="../metadatamodel.cpp" line="135"/>
         <source>Lens model</source>
         <translation>Modelo de la lente</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="131"/>
+        <location filename="../metadatamodel.cpp" line="137"/>
+        <source>Contrast</source>
+        <translation>Contraste</translation>
+    </message>
+    <message>
+        <location filename="../metadatamodel.cpp" line="139"/>
         <source>Brightness</source>
         <translation>Brillo</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="133"/>
+        <location filename="../metadatamodel.cpp" line="141"/>
         <source>Exposure program</source>
         <translation>Programa de exposición</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="135"/>
+        <location filename="../metadatamodel.cpp" line="143"/>
         <source>Saturation</source>
         <translation>Saturación</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="137"/>
+        <location filename="../metadatamodel.cpp" line="145"/>
         <source>Sharpness</source>
         <translation>Nitidez</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="139"/>
+        <location filename="../metadatamodel.cpp" line="147"/>
         <source>White balance</source>
         <translation>Balance de blancos</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="141"/>
+        <location filename="../metadatamodel.cpp" line="149"/>
         <source>Digital zoom</source>
         <translation>Zum digital</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="143"/>
+        <location filename="../metadatamodel.cpp" line="151"/>
         <source>EXIF version</source>
         <translation>Versión de EXIF</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="146"/>
+        <location filename="../metadatamodel.cpp" line="154"/>
         <source>Latitude reference</source>
         <translation>Referencia de la latitud</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="148"/>
+        <location filename="../metadatamodel.cpp" line="156"/>
         <source>Latitude</source>
         <translation>Latitud</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="150"/>
+        <location filename="../metadatamodel.cpp" line="158"/>
         <source>Longitude reference</source>
         <translation>Referencia de la longitud</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="152"/>
+        <location filename="../metadatamodel.cpp" line="160"/>
         <source>Longitude</source>
         <translation>Longitud</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="154"/>
+        <location filename="../metadatamodel.cpp" line="162"/>
         <source>Altitude reference</source>
         <translation>Referencia de la altitud</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="156"/>
+        <location filename="../metadatamodel.cpp" line="164"/>
         <source>Altitude</source>
         <translation>Altitud</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="166"/>
+        <location filename="../metadatamodel.cpp" line="174"/>
         <source>%1 x %2</source>
         <translation>%1 x %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="184"/>
+        <location filename="../metadatamodel.cpp" line="192"/>
         <source>%1 : %2</source>
         <translation>%1 : %2</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="309"/>
+        <location filename="../metadatamodel.cpp" line="317"/>
         <source>Property</source>
         <translation>Propiedad</translation>
     </message>
     <message>
-        <location filename="../metadatamodel.cpp" line="309"/>
+        <location filename="../metadatamodel.cpp" line="317"/>
         <source>Value</source>
         <translation>Valor</translation>
     </message>
@@ -644,62 +654,62 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../settingsdialog.cpp" line="17"/>
+        <location filename="../settingsdialog.cpp" line="21"/>
         <source>Settings</source>
         <translation>Preferencias</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="22"/>
+        <location filename="../settingsdialog.cpp" line="26"/>
         <source>Do nothing</source>
         <translation>No hacer nada</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="23"/>
+        <location filename="../settingsdialog.cpp" line="27"/>
         <source>Close the window</source>
         <translation>Cerrar la ventana</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="24"/>
+        <location filename="../settingsdialog.cpp" line="28"/>
         <source>Toggle maximize</source>
         <translation>Maximizar/desmaximizar</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="28"/>
+        <location filename="../settingsdialog.cpp" line="32"/>
         <source>Zoom in and out</source>
         <translation>Ampliar y reducir</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="29"/>
+        <location filename="../settingsdialog.cpp" line="33"/>
         <source>View next or previous item</source>
         <translation>Mostrar el elemento siguiente/anterior</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="33"/>
+        <location filename="../settingsdialog.cpp" line="37"/>
         <source>Auto size</source>
         <translation>Tamaño automático</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="34"/>
+        <location filename="../settingsdialog.cpp" line="38"/>
         <source>Maximized</source>
         <translation>Maximizar</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="52"/>
+        <location filename="../settingsdialog.cpp" line="56"/>
         <source>Stay on top when start-up</source>
         <translation>Mantener encima al inicio</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="53"/>
+        <location filename="../settingsdialog.cpp" line="57"/>
         <source>Double-click behavior</source>
         <translation>Comportamiento del doble clic</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="54"/>
+        <location filename="../settingsdialog.cpp" line="58"/>
         <source>Mouse wheel behavior</source>
         <translation>Comportamiento de la rueda del ratón</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.cpp" line="55"/>
+        <location filename="../settingsdialog.cpp" line="59"/>
         <source>Default window size</source>
         <translation>Tamaño de la ventana por defecto</translation>
     </message>
@@ -707,12 +717,12 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.cpp" line="31"/>
+        <location filename="../main.cpp" line="38"/>
         <source>Pineapple Pictures</source>
         <translation>Pineapple Pictures</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="35"/>
+        <location filename="../main.cpp" line="42"/>
         <source>File list.</source>
         <translation>Lista de archivos.</translation>
     </message>
